summaryrefslogtreecommitdiff
path: root/sd/source/ui/framework/configuration/ConfigurationUpdater.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sd/source/ui/framework/configuration/ConfigurationUpdater.hxx')
-rw-r--r--sd/source/ui/framework/configuration/ConfigurationUpdater.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/sd/source/ui/framework/configuration/ConfigurationUpdater.hxx b/sd/source/ui/framework/configuration/ConfigurationUpdater.hxx
index 509ebbd9b429..64ff5380ca7a 100644
--- a/sd/source/ui/framework/configuration/ConfigurationUpdater.hxx
+++ b/sd/source/ui/framework/configuration/ConfigurationUpdater.hxx
@@ -116,15 +116,15 @@ private:
css::uno::Reference<
css::drawing::framework::XConfiguration> mxRequestedConfiguration;
/** This flag is set to </TRUE> when an update of the current
configurtion was requested (because the last request in the queue
was processed) but could not be exected because the
ConfigurationController was locked. A call to UpdateConfiguration()
- resets the flag to </FALSE>.
+ resets the flag to </sal_False>.
*/
bool mbUpdatePending;
/** This flag is set to </TRUE> while the UpdateConfiguration() method
is running. It is used to prevent reentrance problems with this
method.
*/
@@ -116,15 +116,15 @@ private:
css::uno::Reference<
css::drawing::framework::XConfiguration> mxRequestedConfiguration;
- /** This flag is set to </TRUE> when an update of the current
+ /** This flag is set to </sal_True> when an update of the current
configurtion was requested (because the last request in the queue
was processed) but could not be exected because the
@@ -116,15 +116,15 @@ private:
*/
bool mbUpdatePending;
- /** This flag is set to </TRUE> while the UpdateConfiguration() method
+ /** This flag is set to </sal_True> while the UpdateConfiguration() method
is running. It is used to prevent reentrance problems with this
method.